.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`graph`
====================
.. automodule:: skimage.graph

.. currentmodule:: skimage.graph
.. autosummary::

   skimage.graph.route_through_array
   skimage.graph.shortest_path

   skimage.graph.MCP
   skimage.graph.MCP_Connect
   skimage.graph.MCP_Flexible
   skimage.graph.MCP_Geometric


route_through_array
-------------------

.. autofunction:: skimage.graph.route_through_array


.. include:: skimage.graph.route_through_array.examples

shortest_path
-------------

.. autofunction:: skimage.graph.shortest_path


.. include:: skimage.graph.shortest_path.examples


:class:`MCP`
------------


.. autoclass:: MCP
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.graph.MCP.examples


:class:`MCP_Connect`
--------------------


.. autoclass:: MCP_Connect
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.graph.MCP_Connect.examples


:class:`MCP_Flexible`
---------------------


.. autoclass:: MCP_Flexible
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.graph.MCP_Flexible.examples


:class:`MCP_Geometric`
----------------------


.. autoclass:: MCP_Geometric
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.graph.MCP_Geometric.examples

